[−][src]Enum swf_parser::parsers::button::ButtonVersion
Variants
Button1Button2Trait Implementations
impl PartialOrd<ButtonVersion> for ButtonVersion[src]
fn partial_cmp(&self, other: &ButtonVersion) -> Option<Ordering>[src]
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<ButtonVersion> for ButtonVersion[src]
fn eq(&self, other: &ButtonVersion) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl Copy for ButtonVersion[src]
impl Ord for ButtonVersion[src]
fn cmp(&self, other: &ButtonVersion) -> Ordering[src]
fn max(self, other: Self) -> Self1.21.0[src]
Compares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
Compares and returns the minimum of two values. Read more
fn clamp(self, min: Self, max: Self) -> Self[src]
clamp)Restrict a value to a certain interval. Read more
impl Eq for ButtonVersion[src]
impl Clone for ButtonVersion[src]
fn clone(&self) -> ButtonVersion[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more