[−][src]Enum swf_parser::parsers::morph_shape::MorphShapeVersion
Variants
MorphShape1MorphShape2Trait Implementations
impl PartialOrd<MorphShapeVersion> for MorphShapeVersion[src]
fn partial_cmp(&self, other: &MorphShapeVersion) -> Option<Ordering>[src]
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<MorphShapeVersion> for MorphShapeVersion[src]
fn eq(&self, other: &MorphShapeVersion) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl Copy for MorphShapeVersion[src]
impl Ord for MorphShapeVersion[src]
fn cmp(&self, other: &MorphShapeVersion) -> Ordering[src]
fn max(self, other: Self) -> Self1.21.0[src]
Compares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
Compares and returns the minimum of two values. Read more
fn clamp(self, min: Self, max: Self) -> Self[src]
clamp)Restrict a value to a certain interval. Read more
impl Eq for MorphShapeVersion[src]
impl Clone for MorphShapeVersion[src]
fn clone(&self) -> MorphShapeVersion[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more